Description Usage Arguments Value Note Examples
brew_version() returns version info about Homebrew, core formulae, and
casks.
1 |
... |
Arguments passed on to
|
A named list containing the following items:
homebrewString describing the version of Homebrew
coreString describing git commit info for core formulae
caskString describing git commit info for casks, if tapped
Version information for installed packages can be retrieved with
brew_list()
1 2 3 4 | ## Not run:
brew_version()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.