Description Usage Arguments Value Examples
brew_cmd() runs a given Homebrew command.
For more information about which additional arguments are supported for a
command, see brew_help().
1 2 3 4 5 6 7 |
cmd |
The command to run (e.g., |
args |
Additional arguments for the command |
brew_cmd |
Optional: Location of |
echo |
Whether to print output and error messages to the screen.
Defaults to |
... |
Additional arguments passed to |
A list with components:
statusThe exit status of the process. If this is NA, then the
process was killed and had no exit status.
stdoutThe standard output of the command, in a character scalar.
stderrThe standard error of the command, in a character scalar.
timeoutWhether the process was killed because of a timeout.
1 2 3 4 | ## Not run:
brew_cmd("install", "unixodbc")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.